@@ -2,6 +2,7 @@
 """
 Diffraction dataset types
 """
+from sys import platform
 from collections import OrderedDict
 from collections.abc import Callable
 from functools import lru_cache, partial
@@ -13,23 +14,16 @@ import numpy as np
 from scipy.ndimage import gaussian_filter
 
 from npstreams import average, itercopy, peek, pmap
-from skued import (
-    azimuthal_average,
-    baseline_dt,
-    combine_masks,
-    electron_wavelength,
-    ialign,
-    mask_from_collection,
-    nfold,
-    powder_calq,
-)
+from skued import __version__, azimuthal_average, baseline_dt, nfold, powder_calq
 from skued.baseline import dt_max_level
 
 from .meta import HDF5ExperimentalParameter, MetaHDF5Dataset
 
 # Whether or not single-writer multiple-reader (SWMR) mode is available
 # See http://docs.h5py.org/en/latest/swmr.html for more information
-SWMR_AVAILABLE = h5py.version.hdf5_version_tuple > (1, 10, 0)
+SWMR_AVAILABLE = (h5py.version.hdf5_version_tuple > (1, 10, 0)) and (
+    platform == "win32"
+)
 
 
 class DiffractionDataset(h5py.File, metaclass=MetaHDF5Dataset):
@@ -72,9 +66,9 @@ class DiffractionDataset(h5py.File, metaclass=MetaHDF5Dataset):
     notes = HDF5ExperimentalParameter("notes", str, default="")
 
     def __repr__(self):
-        rep = "< {} object with following metadata: ".format(type(self).__name__)
+        rep = f"< {type(self).__name__} object with following metadata: "
         for key, val in self.metadata.items():
-            rep += "\n    {key}: {val}".format(key=key, val=val)
+            rep += f"\n    {key}: {val}"
 
         return rep + " >"
 
@@ -89,7 +83,7 @@ class DiffractionDataset(h5py.File, metaclass=MetaHDF5Dataset):
         dtype=None,
         ckwargs=None,
         callback=None,
-        **kwargs
+        **kwargs,
     ):
         """
         Create a DiffractionDataset from a collection of diffraction patterns and metadata.
@@ -176,7 +170,7 @@ class DiffractionDataset(h5py.File, metaclass=MetaHDF5Dataset):
                 name="intensity",
                 shape=resolution + (len(time_points),),
                 dtype=dtype,
-                **ckwargs
+                **ckwargs,
             )
 
             # Making use of the H5DS dimension scales
@@ -213,7 +207,7 @@ class DiffractionDataset(h5py.File, metaclass=MetaHDF5Dataset):
         normalize=True,
         ckwargs=None,
         dtype=None,
-        **kwargs
+        **kwargs,
     ):
         """
         Create a DiffractionDataset from a subclass of AbstractRawDataset.
@@ -325,9 +319,7 @@ class DiffractionDataset(h5py.File, metaclass=MetaHDF5Dataset):
         TypeError : if `func` is not a proper callable
         """
         if not callable(func):
-            raise TypeError(
-                "Expected a callable argument, but received {}".format(type(func))
-            )
+            raise TypeError(f"Expected a callable argument, but received {type(func)}")
 
         if callback is None:
             callback = lambda _: None
@@ -380,6 +372,7 @@ class DiffractionDataset(h5py.File, metaclass=MetaHDF5Dataset):
 
         for index, im in enumerate(transformed):
             dset.write_direct(im, source_sel=np.s_[:, :], dest_sel=np.s_[:, :, index])
+            dset.flush()
             callback(int(100 * index / ntimes))
         self.diff_eq.cache_clear()
 
@@ -423,7 +416,7 @@ class DiffractionDataset(h5py.File, metaclass=MetaHDF5Dataset):
             _symmetrize,
             mod=mod,
             center=center,
-            mask=self.invalid_mask,
+            mask=self.valid_mask,
             kernel_size=kernel_size,
         )
         self.diff_apply(apply, callback=callback, processes=processes)
@@ -501,10 +494,8 @@ class DiffractionDataset(h5py.File, metaclass=MetaHDF5Dataset):
         except TypeError:
             time_index = np.argmin(np.abs(self.time_points - float(timedelay)))
             warn(
-                "Time-delay {}ps not available. Using \
-                 closest-timedelay {}ps instead".format(
-                    timedelay, self.time_points[time_index]
-                )
+                f"Time-delay {timedelay}ps not available. Using \
+                 closest-timedelay {self.time_points[time_index]}ps instead"
             )
         return time_index
 
@@ -668,7 +659,7 @@ class PowderDiffractionDataset(DiffractionDataset):
 
         # TODO: stop writing datasets in __init__
         #       since the GUI will only open datasets in read-mode by default
-        
+
         # Ensure that all required powder groups exist
         maxshape = (len(self.time_points), sqrt(2 * max(self.resolution) ** 2))
         for name in {"intensity", "baseline"}:
@@ -679,7 +670,7 @@ class PowderDiffractionDataset(DiffractionDataset):
                     maxshape=maxshape,
                     dtype=np.float,
                     fillvalue=0.0,
-                    **self.compression_params
+                    **self.compression_params,
                 )
 
         # Radius from center in units of pixels
@@ -939,7 +930,7 @@ class PowderDiffractionDataset(DiffractionDataset):
         # In some cases, it is easier
         if units not in {"pixels", "momentum"}:
             raise ValueError(
-                "``units`` must be either 'pixels' or 'momentum', not {}".format(units)
+                f"``units`` must be either 'pixels' or 'momentum', not {units}"
             )
         abscissa = self.px_radius if units == "pixels" else self.scattering_vector
 
@@ -1056,7 +1047,7 @@ class PowderDiffractionDataset(DiffractionDataset):
             px_radius, avg = azimuthal_average(
                 self.diff_data(timedelay),
                 center=self.center,
-                mask=self.invalid_mask,
+                mask=self.valid_mask,
                 angular_bounds=angular_bounds,
                 trim=False,
             )
