@@ -10,9 +10,12 @@ import pyqtgraph as pg
 from PyQt5 import QtCore, QtGui, QtWidgets
 from skued import diffread
 
+import qdarkstyle
+
 # Get all proper subclasses of AbstractRawDataset
 # to build a loading menu
 from .. import AbstractRawDataset, __author__, __license__, __version__
+from ..dataset import SWMR_AVAILABLE
 from ..plugins import PLUGIN_DIR, install_plugin
 from .angular_average_dialog import AngularAverageDialog
 from .calibrate_q_dialog import QCalibratorDialog
@@ -29,12 +32,11 @@ from .update import UpdateChecker
 
 IMAGE_FOLDER = join(dirname(__file__), "images")
 
-LOAD_PLUGIN_HELP = """You will be prompted to select a plug-in file. This file will be COPIED into:
+INSTALL_PLUGIN_HELP = """You will be prompted to select a plug-in file. This file will be COPIED into:
 
 {dir}
 
-Once this is done, iris will have to restart. 
-The plug-in will remain installed as long as it can be found in the above directory"""
+The plug-in is immediately available. The plug-in will remain installed as long as it can be found in the above directory"""
 
 
 class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
@@ -43,7 +45,6 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
     raw_dataset_path_signal = QtCore.pyqtSignal(str, object)  # path and class
     single_picture_path_signal = QtCore.pyqtSignal(str)
     error_message_signal = QtCore.pyqtSignal(str)
-    restart_signal = QtCore.pyqtSignal()
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -183,15 +184,11 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
 
         self.file_menu = self.menu_bar.addMenu("&File")
         self.file_menu.setToolTipsVisible(True)
-        load_raw_submenu = self.file_menu.addMenu("Load raw dataset...")
+        self.load_raw_submenu = self.file_menu.addMenu("Load raw dataset...")
 
-        # Dynamically add an option for each implementation of AbstractRawDataset
-        # Note : because of dynamical nature of these bindings,
-        # it must be done in a separate method
-        for cls in sorted(
-            AbstractRawDataset.implementations, key=lambda cls: cls.__name__
-        ):
-            self._create_load_raw(cls, load_raw_submenu)
+        # Create the menu based on the currently-available plugins
+        # This can be called multiple times (e.g. when new plugins are installed)
+        self.create_load_raw_menu()
 
         self.load_dataset_action = QtWidgets.QAction(
             QtGui.QIcon(join(IMAGE_FOLDER, "locator.png")), "& Load dataset", self
@@ -236,18 +233,13 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
 
         ###################
         # Plug-in Actions
-        self.load_plugin_action = QtWidgets.QAction(
-            QtGui.QIcon(join(IMAGE_FOLDER, "eye.png")),
-            "& Install plug-in (restarts program)",
-            self,
+        self.install_plugin_action = QtWidgets.QAction(
+            QtGui.QIcon(join(IMAGE_FOLDER, "eye.png")), "& Install plug-in", self
         )
-        self.load_plugin_action.setToolTip(
-            "Copy a plug-in file into the internal storage. The application will restart and the new plug-in will be available."
+        self.install_plugin_action.setToolTip(
+            "Copy a plug-in file into the internal storage. The new plug-in will be available immediately."
         )
-        self.load_plugin_action.triggered.connect(self.load_plugin)
-        self.controller.operation_in_progress.connect(
-            self.load_plugin_action.setDisabled
-        )  # wouldn't want to restart during processing
+        self.install_plugin_action.triggered.connect(self.install_plugin)
 
         self.open_plugin_directory_action = QtWidgets.QAction(
             QtGui.QIcon(join(IMAGE_FOLDER, "eye.png")), "& Open plug-in directory", self
@@ -268,7 +260,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         )
 
         self.plugin_menu = self.menu_bar.addMenu("Plug-ins")
-        self.plugin_menu.addAction(self.load_plugin_action)
+        self.plugin_menu.addAction(self.install_plugin_action)
         self.plugin_menu.addAction(self.open_plugin_directory_action)
         self.plugin_menu.addSeparator()
         self.plugin_menu.addAction(self.howto_write_plugin_action)
@@ -542,12 +534,22 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         self.update_checker.update_available_signal.connect(self.update_available)
         self.update_checker.start()
 
-    def _create_load_raw(self, cls, submenu):
+    def create_load_raw_menu(self):
+        # Dynamically add an option for each implementation of AbstractRawDataset
         # Note : because of dynamical nature of these bindings,
-        # it must be done in a separate method
-        return submenu.addAction(
+        # it must be done in a separate method (_create_load_raw)
+        # Otherwise, it doesn't work correctly
+        self.load_raw_submenu.clear()
+
+        for rawdatacls in sorted(
+            AbstractRawDataset.implementations, key=lambda c: c.display_name
+        ):
+            self._create_load_raw(rawdatacls, self.load_raw_submenu)
+
+    def _create_load_raw(self, cls, submenu):
+        submenu.addAction(
             QtGui.QIcon(join(IMAGE_FOLDER, "locator.png")),
-            "&Load {}".format(cls.__name__),
+            f"&{cls.display_name}",
             lambda: self.load_raw_dataset(cls),
         )
 
@@ -699,9 +701,9 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         self.move(qr.topLeft())
 
     @QtCore.pyqtSlot()
-    def load_plugin(self):
-        """ Load plug-in and restart application. """
-        explanation = LOAD_PLUGIN_HELP.format(dir=PLUGIN_DIR)
+    def install_plugin(self):
+        """ Load plug-in. """
+        explanation = INSTALL_PLUGIN_HELP.format(dir=PLUGIN_DIR)
 
         QtWidgets.QMessageBox.information(self, "Loading a plug-in", explanation)
 
@@ -712,10 +714,7 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
             return
 
         install_plugin(path)
-
-        self.controller.close_dataset()
-        self.controller.close_raw_dataset()
-        self.restart_signal.emit()
+        self.create_load_raw_menu()
 
     @QtCore.pyqtSlot()
     def show_about(self):
@@ -738,6 +737,7 @@ def make_about_string():
     <b>License</b>: {__license__}                    <br>
     <b>Author</b>: {__author__}                      <br>
     <b>Install location</b>: {Path(__file__).parent} <br> 
+    <b>SWMR available</b>: {SWMR_AVAILABLE}          <br>
 
     <h3>Versions</h3>
     <table style="width:100%">
@@ -753,6 +753,10 @@ def make_about_string():
             <td style="padding-right:75">Qt</td>
             <td align="right">{QtCore.qVersion()}</td>
         </tr>
+        <tr>
+            <td style="padding-right:75">qdarkstyle</td>
+            <td align="right">{qdarkstyle.__version__}</td>
+        </tr>
         <tr>
             <td style="padding-right:75">PyQtGraph</td>
             <td align="right">{pyqtgraph.__version__}</td>
